#ifndef IDAFILE_H
#define IDAFILE_H

#ifdef V_IDA

/*{{{  << DESCRIPTION -- Format of 'ida' records >>*/
/*-------------------------------------------------------------------
Format of IDA records
---------------------
entity-let  name  $  [type-let [(shape)]  $]  [lineno  usage-str  $]...

where $ == IDA_FIELD_SEPARATOR  (' ' for now; *** SHOULD CHANGE TO,E.G.'\t'? ***)

entity-let (e)
--------------
e = F -- function definition  (typed)
    S -- subroutine definition
    P -- main program definition
(don't output anything for: block data / module)

    d -- dummy variable   (typed)  -- (used for all dummy args at moment!)
    n -- dummy function   (typed)
    o -- dummy subroutine
    p -- dummy procedure  (unknown proc-type)
    
    c -- common block
    g -- global variable  (typed)
    l -- local variable   (typed)

    f -- external function  (typed)
    s -- external subroutine
    e -- external procedure (unknown proc-type)

type-let
--------
    i -- TY_INTEGER
    r -- TY_REAL
    d -- TY_DP
    c -- TY_COMPLEX
    l -- TY_LOGICAL
    C [{char-len}] -- TY_CHARACTER
    t -- TY_DERIVED

usage-str
---------
    r   -- READ
    w   -- WRITE
    a%d%s  -- variable passed as actual argument # (%d) to proc '%s'
    b%d%s  -- procedure passed as actual argument # (%d) to proc '%s'
    p([arg-list])  -- proc ref with its argument list

In the last case, each 'arg' is one of the following  (*not* preceded
by a lineno):
    V{%s} -- a variable actual argument (%s) in a proc ref
    P{%s} -- a procedure actual argument (%s) in a proc ref
    A -- alternate return argument
    I -- integer          }
    R -- real             }
    D -- double precision }
    C -- complex          } expression actual argument
    L -- logical          }
    X -- character        }
    Y -- derived type     }
    N -- *no type* (an error, incl illegal args, e.g. subscript triplets)
-------------------------------------------------------------------*/

/*}}}*/
/*{{{  #defines*/
/*--------------------------------------------------------------*/
/* IDA_PREFIX and IDA_VERSION are the first 2 'word's of the	*/
/* first line of the 'ida' file.				*/
/*--------------------------------------------------------------*/
#define  IDA_PREFIX		"<<ida>>: "
#define  IDA_PREFIX_LEN		9
#define  IDA_VERSION		"v0.3 "
#define  IDA_VERSION_LEN	5

/*--------------------------------------*/
/* notation used in 'ida' records	*/
/*--------------------------------------*/
#define  IDA_FIELD_SEP		' '	/* a space char! */
#define  IDA_OPEN_PAREN		'{'
#define  IDA_CLOSE_PAREN	'}'
/*}}}*/

#endif

#endif
